==> jc-1.4.0.tar.gz: java/util/LinkedList__24Entry.h <==
// final class java.util.LinkedList$Entry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2522cc4453ab9d02 java_util_LinkedList__24Entry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_LinkedList__24Entry_H_
#define _JC_java_util_LinkedList__24Entry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList__24Entry$object;

// Typedefs
typedef struct _jc_java_util_LinkedList__24Entry$sub_refs	_jc_java_util_LinkedList__24Entry$sub_refs;
typedef struct _jc_java_util_LinkedList__24Entry$sub_nonrefs	_jc_java_util_LinkedList__24Entry$sub_nonrefs;
typedef struct _jc_java_util_LinkedList__24Entry$refs	_jc_java_util_LinkedList__24Entry$refs;
typedef struct _jc_java_util_LinkedList__24Entry$nonrefs	_jc_java_util_LinkedList__24Entry$nonrefs;
typedef struct _jc_java_util_LinkedList__24Entry$object	_jc_java_util_LinkedList__24Entry$object;

typedef const struct _jc_java_util_LinkedList__24Entry$vmethods	_jc_java_util_LinkedList__24Entry$vmethods;
typedef const struct _jc_java_util_LinkedList__24Entry$vtable	_jc_java_util_LinkedList__24Entry$vtable;
typedef const struct _jc_java_util_LinkedList__24Entry$vtype	_jc_java_util_LinkedList__24Entry$vtype;

// Constructors
extern void _jc_java_util_LinkedList__24Entry$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_util_LinkedList__24Entry$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_java_util_LinkedList__24Entry$vmethods {
};

// Vtable
struct _jc_java_util_LinkedList__24Entry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_LinkedList__24Entry$vmethods	java_util_LinkedList__24Entry;
};

// Vtype
struct _jc_java_util_LinkedList__24Entry$vtype {
	_jc_type			type;
	_jc_java_util_LinkedList__24Entry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LinkedList__24Entry$sub_refs {
	struct _jc_java_lang_Object$object	*data;
	struct _jc_java_util_LinkedList__24Entry$object	*next;
	struct _jc_java_util_LinkedList__24Entry$object	*previous;
};

// Reference instance fields (object)
struct _jc_java_util_LinkedList__24Entry$refs {
    _jc_java_util_LinkedList__24Entry$sub_refs	java_util_LinkedList__24Entry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LinkedList__24Entry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LinkedList__24Entry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_LinkedList__24Entry$sub_nonrefs	java_util_LinkedList__24Entry;
};

// Object instance structure
struct _jc_java_util_LinkedList__24Entry$object {
	_jc_java_util_LinkedList__24Entry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LinkedList__24Entry$vtype	*vtype;
	_jc_java_util_LinkedList__24Entry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LinkedList__24Entry$vtype _jc_java_util_LinkedList__24Entry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LinkedList__24Entry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LinkedList__24Entry$class_object;

#endif	/* _JC_java_util_LinkedList__24Entry_H_ */

==> jc-1.4.6.tar.gz: java/util/LinkedList__24Entry.h <==
// final class java.util.LinkedList$Entry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2522cc4453ab9d02 java_util_LinkedList__24Entry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_LinkedList__24Entry_H_
#define _JC_java_util_LinkedList__24Entry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList__24Entry$object;

// Typedefs
typedef struct _jc_java_util_LinkedList__24Entry$sub_refs	_jc_java_util_LinkedList__24Entry$sub_refs;
typedef struct _jc_java_util_LinkedList__24Entry$sub_nonrefs	_jc_java_util_LinkedList__24Entry$sub_nonrefs;
typedef struct _jc_java_util_LinkedList__24Entry$refs	_jc_java_util_LinkedList__24Entry$refs;
typedef struct _jc_java_util_LinkedList__24Entry$nonrefs	_jc_java_util_LinkedList__24Entry$nonrefs;
typedef struct _jc_java_util_LinkedList__24Entry$object	_jc_java_util_LinkedList__24Entry$object;

typedef const struct _jc_java_util_LinkedList__24Entry$vmethods	_jc_java_util_LinkedList__24Entry$vmethods;
typedef const struct _jc_java_util_LinkedList__24Entry$vtable	_jc_java_util_LinkedList__24Entry$vtable;
typedef const struct _jc_java_util_LinkedList__24Entry$vtype	_jc_java_util_LinkedList__24Entry$vtype;

// Constructors
extern void _jc_java_util_LinkedList__24Entry$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_util_LinkedList__24Entry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_LinkedList__24Entry$vmethods {
};

// Vtable
struct _jc_java_util_LinkedList__24Entry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_LinkedList__24Entry$vmethods	java_util_LinkedList__24Entry;
};

// Vtype
struct _jc_java_util_LinkedList__24Entry$vtype {
	_jc_type			type;
	_jc_java_util_LinkedList__24Entry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LinkedList__24Entry$sub_refs {
	struct _jc_java_lang_Object$object	*data;
	struct _jc_java_util_LinkedList__24Entry$object	*next;
	struct _jc_java_util_LinkedList__24Entry$object	*previous;
};

// Reference instance fields (object)
struct _jc_java_util_LinkedList__24Entry$refs {
    _jc_java_util_LinkedList__24Entry$sub_refs	java_util_LinkedList__24Entry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LinkedList__24Entry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LinkedList__24Entry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_LinkedList__24Entry$sub_nonrefs	java_util_LinkedList__24Entry;
};

// Object instance structure
struct _jc_java_util_LinkedList__24Entry$object {
	_jc_java_util_LinkedList__24Entry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LinkedList__24Entry$vtype	*vtype;
	_jc_java_util_LinkedList__24Entry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LinkedList__24Entry$vtype _jc_java_util_LinkedList__24Entry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LinkedList__24Entry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LinkedList__24Entry$class_object;

#endif	/* _JC_java_util_LinkedList__24Entry_H_ */
